@@ -6,6 +6,7 @@ Created by Eric Lo on 2010-05-20.
 Copyright (c) 2010 __lxneng@gmail.com__. http://lxneng.com All rights reserved.
 """
 
+__import__('pkg_resources').declare_namespace(__name__)
 
 import os.path
 
@@ -38,9 +39,8 @@ class Pinyin():
         for line in open(self.data_path):
             k, v = line.split('\t')
             self.dict[k] = v
-        self.splitter = ''
 
-    def get_pinyin(self, chars=u'你好'):
+    def get_pinyin(self, chars=u'你好', splitter=''):
         result = []
         for char in chars:
             key = "%X" % ord(char)
@@ -49,7 +49,7 @@ class Pinyin():
                         .lower())
             except:
                 result.append(char)
-        return self.splitter.join(result)
+        return splitter.join(result)
 
     def get_initials(self, char=u'你'):
         try:
